@@ -2,7 +2,7 @@
 
 """waltz: make web apps in 3/4 time (http://github.com/mekarpeles/waltz)"""
 
-__version__ = "0.1.64"
+__version__ = "0.1.65"
 __author__ = [
     "Mek <michael.karpeles@gmail.com>"
 ]
@@ -16,7 +16,7 @@ session = lambda: getattr(web.ctx, 'session', None)
 # (unless base template name is overridden)
 render = lambda: getattr(web.ctx, 'render', None)
 # slim render: renders a template by itself with no base template
-slender = lambda: getattr(web.ctx, 'render', None)
+slender = lambda: getattr(web.ctx, 'slender', None)
 # db for waltz analytics, etc.
 db = lambda: Db(web.ctx['waltz']['db'])
 
@@ -25,6 +25,7 @@ from decorations import *
 from utils import *
 from treasury import *
 from setup import *
+from modules import rss
 
 class User(Account):
     """Extends Account to use LazyDB as Datastore"""
